%global eclipse_dropin %{_datadir}/eclipse/dropins
%global gittag R3_3_0

Name:      eclipse-pdt
Version:   3.3.0
Release:   3%{?dist}
Summary:   PHP Development Tools (PDT) Eclipse plugin
License:   EPL
URL:       http://www.eclipse.org/pdt/
Source0:   http://git.eclipse.org/c/pdt/org.eclipse.pdt.git/snapshot/org.eclipse.pdt-%{gittag}.tar.bz2

# The lexer/parser code generated by the Fedora version of jflex causes test failures at build time and buggy
# behaviour at runtime so we have pre-generated the parser code using upstream's preferred version of jflex.
# This source tarball was generated with the following commands:
#   $ (cd plugins/org.eclipse.php.core/Resources/parserTools/build.xml && ant)
#   $ tar -czf code_gen.tar.gz $(find -name ParserConstants.java -o -name PhpAstLexer.java -o -name PhpAstParser.java -o -name DocumentorLexer.java -o -name CompilerAstParser.java -o -name CompilerParserConstants.java -o -name CompilerAstParser.java -o -name PHPTokenizer.java -o -name PhpLexer.java)
Source1:   code_gen.tar.gz

# Minor fix to expectation of CSS formatting
Patch0:    eclipse-pdt-test-expectation.patch

BuildArch:        noarch

BuildRequires:    java-devel
BuildRequires:    jpackage-utils
BuildRequires:    eclipse-pde
BuildRequires:    eclipse-tests
BuildRequires:    eclipse-dltk
BuildRequires:    eclipse-dltk-mylyn
BuildRequires:    eclipse-wtp-common
BuildRequires:    eclipse-wtp-sourceediting
BuildRequires:    eclipse-license
BuildRequires:    tycho
BuildRequires:    java_cup >= 0.11a-15
BuildRequires:    xorg-x11-server-Xvfb

Requires:         php
Requires:         php-pecl-xdebug

%description
The PHP IDE project delivers a PHP Integrated Development Environment
framework for the Eclipse platform. This project encompasses the development
components necessary to develop PHP-based Web Applications and facilitates
extensibility. It leverages the existing Web Tools Project in providing
developers with PHP capabilities.

%package   mylyn
Summary:   Mylyn integration for Eclipse PDT projects
Requires:  %{name} = %{version}-%{release}

%description mylyn
Mylyn task-focused UI integration for Eclipse PHP Development Tools (PDT)
projects.

%package   sdk
Summary:   Eclipse PDT SDK
Requires:  eclipse-pde
Requires:  %{name}       = %{version}-%{release}
Requires:  %{name}-mylyn = %{version}-%{release}

%description sdk
Documentation and source for the Eclipse PHP Development Tools (PDT).

%package   tests
Summary:   Eclipse PDT Tests

%description tests
Tests for Eclipse PHP Development Tools (PDT).

%prep
%setup -q -n org.eclipse.pdt-%{gittag}

%patch0

# Extract pre-generated code
tar xf %{SOURCE1}

# Remove bundled binaries
find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;

# Remove plugins not needed
%pom_remove_plugin org.jboss.tools.tycho-plugins:repository-utils dev/org.eclipse.php-repository
%pom_remove_plugin org.eclipse.tycho:tycho-packaging-plugin org.eclipse.pdt.releng
%pom_remove_plugin org.jacoco:jacoco-maven-plugin org.eclipse.pdt.releng

# Skip code generation
%pom_remove_plugin :maven-antrun-plugin plugins/org.eclipse.php.core

# Make sure mylyn is included in auto-generated package requires
sed -i -e 's@;resolution:=optional@@g' plugins/org.eclipse.php.mylyn.ui/META-INF/MANIFEST.MF

# Add java_cup as an OSGi dep instead of bundling
echo "Require-Bundle: java_cup" >> plugins/org.eclipse.php.core.parser/META-INF/MANIFEST.MF

%build
pushd org.eclipse.pdt.releng
xvfb-run xmvn -o clean verify
popd

%install
install -d -m 755 %{buildroot}%{eclipse_dropin}/pdt-tests/eclipse/{plugins,features}
install -d -m 755 %{buildroot}%{eclipse_dropin}/pdt-sdk/eclipse/{plugins,features}
install -d -m 755 %{buildroot}%{eclipse_dropin}/pdt-mylyn/eclipse/{plugins,features}
install -d -m 755 %{buildroot}%{eclipse_dropin}/pdt/eclipse/{plugins,features}

pushd dev/org.eclipse.php-repository/target/repository
mv plugins/org.eclipse.php*test* %{buildroot}%{eclipse_dropin}/pdt-tests/eclipse/plugins
mv features/org.eclipse.php*test* %{buildroot}%{eclipse_dropin}/pdt-tests/eclipse/features

mv plugins/org.eclipse.php*source* %{buildroot}%{eclipse_dropin}/pdt-sdk/eclipse/plugins
mv features/org.eclipse.php*source* %{buildroot}%{eclipse_dropin}/pdt-sdk/eclipse/features

mv plugins/org.eclipse.php*mylyn* %{buildroot}%{eclipse_dropin}/pdt-mylyn/eclipse/plugins
mv features/org.eclipse.php*mylyn* %{buildroot}%{eclipse_dropin}/pdt-mylyn/eclipse/features

mv plugins/org.eclipse.php* %{buildroot}%{eclipse_dropin}/pdt/eclipse/plugins
mv features/org.eclipse.php* %{buildroot}%{eclipse_dropin}/pdt/eclipse/features
popd

# Symlinks for system deps
ln -s $(build-classpath java_cup) %{buildroot}/%{eclipse_dropin}/pdt/eclipse/plugins/java_cup.jar

%files
%{eclipse_dropin}/pdt
%doc features/org.eclipse.php-feature/*.html

%files mylyn
%{eclipse_dropin}/pdt-mylyn
%doc features/org.eclipse.php-feature/*.html

%files sdk
%{eclipse_dropin}/pdt-sdk
%doc features/org.eclipse.php-feature/*.html

%files tests
%{eclipse_dropin}/pdt-tests
%doc features/org.eclipse.php-feature/*.html

%changelog
* Tue Jun 24 2014 Mat Booth <mat.booth@redhat.com> - 3.3.0-3
- No longer need to copy license feature on F20

* Mon Jun 16 2014 Mat Booth <mat.booth@redhat.com> - 3.3.0-2
- Copy shared license feature, allowing building on F20

* Fri Jun 13 2014 Mat Booth <mat.booth@redhat.com> - 3.3.0-1
- Update to latest release
- Use pre-generated parser code

* Tue Mar 11 2014 Mat Booth <fedora@matbooth.co.uk> - 3.2.0-3.git0be0c838
- Enable tests, run them with a virtual frame buffer

* Mon Feb 10 2014 Mat Booth <fedora@matbooth.co.uk> 3.2.0-2.git0be0c838
- Update to post-release snapshot for PHP 5.5 and Eclipse >= 4.3 support
- Drop upstreamed patch

* Sat Aug 31 2013 Mat Booth <fedora@matbooth.co.uk> 3.2.0-1
- Initial release, based loosely on the eclipse-dltk spec.

